==> vertica_connector_talenttech-1.0.9-py3-none-any.whl: vconnector/vertica_connector.py <==
import time
import sys
import logging
import os
import vertica_python

logging.basicConfig(stream=sys.stdout, level=logging.INFO)
logging.captureWarnings(True)


def read_commands_from_file(path):
    f = open(path, "r")
    ddl_txt = f.read()
    commands = [x + ";" for x in ddl_txt.replace("\n", "").split(";") if x != ""]
    return commands


class VerticaConnector:
    def __init__(
        self,
        user,
        password,
        database,
        vertica_configs,
        debug=True,
        sec_to_recconect=5,
        count_retries=1,
    ):

        """ pass params to connector
        :param user user in connection info
        :type  str
        :param password password in connection info
        :type  str
        :param database
        :type str
        :param vertica_configs - other  required params including host, port, connection_load_balance, backup_server_node
        :param sec_to_recconect: seconds to reconnect
        :param count_retries
        """

        self.sec_to_recconect = sec_to_recconect or 5
        self.count_retries = count_retries
        self.connection_info = vertica_configs
        self.connection_info["user"] = user
        self.connection_info["connection_load_balance"] = True
        self.connection_info["password"] = password
        self.connection_info["database"] = database
        self.debug = debug
        self.cnx = None
        if "backup_server_node" not in self.connection_info:
            raise BaseException(
                "Error. You should specify backup_server_node list in connection_info"
            )
        elif len(self.connection_info["backup_server_node"]) == 0:
            raise BaseException(
                "Error. backup_server_node list has to contain at least one backup node"
            )
        if (
            "connection_load_balance" not in self.connection_info
            or not self.connection_info["connection_load_balance"]
        ):
            raise BaseException(
                "Error. You have to specify connection_load_balance=True param"
            )
        for param in ["host", "port", "user", "password", "database"]:
            if param not in self.connection_info:
                raise BaseException("Error. You have to specify {} param".format(param))
        self.foreign_keys_ddl = []

    def __str__(self):
        return "VerticaConnector to {}".format(self.connection_info["database"])

    def exec_commands_from_file(self, path):
        self.exec_multiple_sql(read_commands_from_file(path))

    def exec_multiple_sql(self, sqls):
        """
        EXEC list of sql queries
        :param sqls: list of sql queries
        :return: nothing
        """
        if self.cnx is not None:
            cur = self.cnx.cursor()
        else:
            raise Exception("Execution should be in with method")
        cur.execute("START TRANSACTION;")
        for sql in sqls:
            logging.info(sql)
            cur.execute(sql)
        cur.execute("COMMIT;")

    def reload_main_table(self, table_name, schema, staging_schema):
        sqls = [
            "drop table {schema}.{table_name} cascade;",
            "alter table {staging_schema}.{table_name} set schema {schema};",
            "drop table if exists {staging_schema}.{table_name} cascade;",
        ]
        sqls = [
            sql.format(
                schema=schema, table_name=table_name, staging_schema=staging_schema,
            )
            for sql in sqls
        ] + self.foreign_keys_ddl
        self.exec_multiple_sql(sqls)

    def create_staging_table(self, table_name, schema, staging_schema, ddl_path):
        """
        Create temporary table in staging schema
        :param table_name:
        :param schema:
        :param staging_schema:
        :param ddl_path: path to ddl for read
        :return:
        """
        commands = read_commands_from_file(ddl_path + "/" + table_name + ".sql")
        ddls = [
            dd.replace(schema + "." + table_name, staging_schema + "." + table_name,)
            for dd in commands
        ]
        self.foreign_keys_ddl = ddls[1:]
        sqls = [
            "drop table if exists {staging_schema}.{table_name} cascade;".format(
                staging_schema=staging_schema, table_name=table_name
            )
        ] + ddls
        self.exec_multiple_sql(sqls)

    def __enter__(self):
        """ start point to connect """
        if self.debug:
            logging.info("Connecting to Vertica...")
        for i in range(self.count_retries + 1):
            try:
                self.cnx = vertica_python.connect(**self.connection_info)
                break
            except vertica_python.errors.ConnectionError as E:
                logging.info(
                    "{}, waiting {} sec to reconnect".format(
                        str(E), self.sec_to_recconect
                    )
                )
                time.sleep(self.sec_to_recconect)

        if self.debug:
            cur = self.cnx.cursor("dict")
            sql_sessions = """SELECT node_name, client_hostname, session_id, login_timestamp, transaction_id, client_version FROM CURRENT_SESSION"""
            cur.execute(sql_sessions)
            row = cur.fetchone()
            params = []
            for key, value in row.items():
                params.append(str(key) + ": " + str(value))

            logging.info(
                "Connected to Vertica: {current_session_info}".format(
                    current_session_info=", ".join(params)
                )
            )
        return self

    def __exit__(self, type, value, traceback):
        self.cnx.close()
        if self.debug:
            logging.info("Vertica connection closed")

==> vertica_connector_talenttech-1.1.0-py3-none-any.whl: vconnector/vertica_connector.py <==
import time
import sys
import logging
import os
import vertica_python

logging.basicConfig(stream=sys.stdout, level=logging.INFO)
logging.captureWarnings(True)


def read_commands_from_file(path):
    f = open(path, "r")
    ddl_txt = f.read()
    commands = [x + ";" for x in ddl_txt.replace("\n", "").split(";") if x != ""]
    return commands


class VerticaConnector:
    def __init__(
        self,
        user,
        password,
        database,
        vertica_configs,
        debug=True,
        sec_to_recconect=5,
        count_retries=1,
    ):

        """ pass params to connector
        :param user user in connection info
        :type  str
        :param password password in connection info
        :type  str
        :param database
        :type str
        :param vertica_configs - other  required params including host, port, connection_load_balance, backup_server_node
        :param sec_to_recconect: seconds to reconnect
        :param count_retries
        """

        self.sec_to_recconect = sec_to_recconect or 5
        self.count_retries = count_retries
        self.connection_info = vertica_configs
        self.connection_info["user"] = user
        self.connection_info["connection_load_balance"] = True
        self.connection_info["password"] = password
        self.connection_info["database"] = database
        self.debug = debug
        self.cnx = None
        if "backup_server_node" not in self.connection_info:
            raise BaseException(
                "Error. You should specify backup_server_node list in connection_info"
            )
        elif len(self.connection_info["backup_server_node"]) == 0:
            raise BaseException(
                "Error. backup_server_node list has to contain at least one backup node"
            )
        if (
            "connection_load_balance" not in self.connection_info
            or not self.connection_info["connection_load_balance"]
        ):
            raise BaseException(
                "Error. You have to specify connection_load_balance=True param"
            )
        for param in ["host", "port", "user", "password", "database"]:
            if param not in self.connection_info:
                raise BaseException("Error. You have to specify {} param".format(param))
        self.foreign_keys_ddl = []

    def __str__(self):
        return "VerticaConnector to {}".format(self.connection_info["database"])

    def exec_commands_from_file(self, path):
        self.exec_multiple_sql(read_commands_from_file(path))

    def exec_multiple_sql(self, sqls):
        """
        EXEC list of sql queries
        :param sqls: list of sql queries
        :return: nothing
        """
        if self.cnx is not None:
            cur = self.cnx.cursor()
        else:
            raise Exception("Execution should be in  with method")
        cur.execute("START TRANSACTION;")
        for sql in sqls:
            logging.info(sql)
            cur.execute(sql)
        cur.execute("COMMIT;")

    def reload_main_table(self, table_name, schema, staging_schema):
        sqls = [
            "drop table {schema}.{table_name} cascade;",
            "alter table {staging_schema}.{table_name} set schema {schema};",
            "drop table if exists {staging_schema}.{table_name} cascade;",
        ]
        sqls = [
            sql.format(
                schema=schema, table_name=table_name, staging_schema=staging_schema,
            )
            for sql in sqls
        ] + self.foreign_keys_ddl
        self.exec_multiple_sql(sqls)

    def create_staging_table(self, table_name, schema, staging_schema, ddl_path):
        """
        Create temporary table in staging schema
        :param table_name:
        :param schema:
        :param staging_schema:
        :param ddl_path: path to ddl for read
        :return:
        """
        commands = read_commands_from_file(ddl_path + "/" + table_name + ".sql")
        commands[0] = commands[0].replace(schema + "." + table_name, staging_schema + "." + table_name)
        self.foreign_keys_ddl = commands[1:]
        sqls = [
            "drop table if exists {staging_schema}.{table_name} cascade;".format(
                staging_schema=staging_schema, table_name=table_name
            )
        ] + commands[0:1]
        self.exec_multiple_sql(sqls)

    def __enter__(self):
        """ start point to connect """
        if self.debug:
            logging.info("Connecting to Vertica...")
        for i in range(self.count_retries + 1):
            try:
                self.cnx = vertica_python.connect(**self.connection_info)
                break
            except vertica_python.errors.ConnectionError as E:
                logging.info(
                    "{}, waiting {} sec to reconnect".format(
                        str(E), self.sec_to_recconect
                    )
                )
                time.sleep(self.sec_to_recconect)

        if self.debug:
            cur = self.cnx.cursor("dict")
            sql_sessions = """SELECT node_name, client_hostname, session_id, login_timestamp, transaction_id, client_version FROM CURRENT_SESSION"""
            cur.execute(sql_sessions)
            row = cur.fetchone()
            params = []
            for key, value in row.items():
                params.append(str(key) + ": " + str(value))

            logging.info(
                "Connected to Vertica: {current_session_info}".format(
                    current_session_info=", ".join(params)
                )
            )
        return self

    def __exit__(self, type, value, traceback):
        self.cnx.close()
        if self.debug:
            logging.info("Vertica connection closed")
